@@ -63,7 +63,7 @@ class InstaLiveCLI:
     IG_SIG_KEY = '4f8732eb9ba7d1c8e8897a75d6474d4eb3f5279137431b2aafb71fafe2abe178'
     SIG_KEY_VERSION = '4'
 
-    def __init__(self, username='', password='', settings='', auth=''):
+    def __init__(self, username='', password='', settings='', auth='', saved=False):
         """Initiate InstaLiveCLI
 
         Args:
@@ -84,14 +84,15 @@ class InstaLiveCLI:
             username = args.username
             password = args.password
 
-            if args.save:
-                self.save_settings = True
-        
+
         if settings:
             self.import_settings(settings)
         elif auth:
             self.load_settings(auth)
 
+        if saved:
+            self.save_settings = True
+
         m = hashlib.md5()
         m.update(username.encode('utf-8') + password.encode('utf-8'))
         self.device_id = self.generate_device_id(m.hexdigest())
@@ -116,9 +117,25 @@ class InstaLiveCLI:
             'device_id': self.device_id,
             'cookie': self.cookie_jar.dump(self.s.cookies),
             'isLoggedIn': self.isLoggedIn, # !todo: check expiration date cookies
+            'data_stream': {
+                'broadcast_id':self.broadcast_id,
+                'stream_server': self.stream_server,
+                'stream_key': self.stream_key,
+                'status':  self.get_broadcast_status()
+            },
             'created_ts': int(time.time())
         }
     
+    def get_broadcast_status(self):
+        """Returning current broadcast info status if exists
+
+        Returns:
+            str: broadcast status
+        """
+        if self.send_request("live/{}/info/".format(self.broadcast_id)):
+            return self.LastJson['broadcast_status']
+        return None
+    
     def export_settings(self, filename):
         """Exporting all the settings to json file
 
@@ -156,6 +173,10 @@ class InstaLiveCLI:
         self.device_id = cached_auth['device_id']
         self.isLoggedIn = cached_auth['isLoggedIn']
 
+        # streaming data
+        self.broadcast_id = cached_auth['data_stream']['broadcast_id']
+        self.stream_key = cached_auth['data_stream']['stream_key']
+        self.stream_server = cached_auth['data_stream']['stream_server']
     def load_cookies(self, cookie_string):
         """Loads cookie from Cookiestring to Cookie jar and then import it to session's cookiejar
 
